@@ -1,5 +1,8 @@
 #!/bin/sh
-#  canonical test suite for fourfit
+#
+# $Id: chk_alist.sh 330 2011-06-10 13:32:10Z gbc $
+#
+# canonical test suite for alist
 #
 
 verb=false
@@ -14,7 +17,7 @@ export DATADIR=`pwd`
 time=oifhak
 
 files=`ls -1 ??.?.?.$time | wc -l`
-[ "$files" -gt 0 ] || { echo missing files--run chk_ffb_2843.sh; exit 2; }
+[ "$files" -gt 0 ] || { echo missing files--run chk_baselines.sh; exit 2; }
 
 rm -f alist.out
 
