@@ -50,7 +50,8 @@ init_tokens ()
     tokenize (PC_TONEMASK_, "pc_tonemask",CHAN_PARAM)
     tokenize (LSB_OFFSET_,  "lsb_offset", FLOAT_PARAM)
     tokenize (SB_WIN_,      "sb_win",     TWO_FLOAT_PARAM)
-    tokenize (MB_WIN_,      "mb_win",     TWO_FLOAT_PARAM) tokenize (DR_WIN_,      "dr_win",     TWO_FLOAT_PARAM)
+    tokenize (MB_WIN_,      "mb_win",     TWO_FLOAT_PARAM) 
+    tokenize (DR_WIN_,      "dr_win",     TWO_FLOAT_PARAM)
     tokenize (SKIP_,        "skip",       INT_PARAM)
     tokenize (WILDCARD_,    "?",          ONE_CHAR)
     tokenize (INT_,         "~INTEGER~",  INTEGER)
@@ -107,5 +108,8 @@ init_tokens ()
     tokenize (WEAK_CHANNEL_,"weak_channel", FLOAT_PARAM)
     tokenize (PC_AMP_HCODE_,"pc_amp_hcode", FLOAT_PARAM)
     tokenize (FMATCH_BW_PCT_,"fmatch_bw_pct", FLOAT_PARAM)
+    tokenize (FILE_,        "file",       INT_CONST + PHYLE)
+    tokenize (ADHOC_FILE_,  "adhoc_file", STRING_PARAM)
+    tokenize (ADHOC_FILE_CHANS_, "adhoc_file_chans", STRING_PARAM)
     }
 
