@@ -46,11 +46,13 @@
 #define pscat(ps_string) strcat (pplot, ps_string)
 #define psleft(xcoord, ycoord, ps_string)\
              {xval = xcoord * 7570; yval = ycoord * 10500;\
-                sprintf (psbuf, "%d %d M (%s) SL\n", xval, yval, ps_string);\
+                snprintf (psbuf, sizeof(psbuf),\
+                    "%d %d M (%s) SL\n", xval, yval, ps_string);\
                 pscat (psbuf);}
 #define psright(xcoord, ycoord, ps_string)\
              {xval = xcoord * 7570; yval = ycoord * 10500;\
-                sprintf (psbuf, "%d %d M (%s) SR\n", xval, yval, ps_string);\
+                snprintf (psbuf, sizeof(psbuf),\
+                    "%d %d M (%s) SR\n", xval, yval, ps_string);\
                 pscat (psbuf);}
                                         /* Color shorthand */
 #define setred pscat ("1.0 0.0 0.0 setrgbcolor\n")
@@ -115,7 +117,7 @@ struct type_221 **t221)
     int i, line, j, maxj, k, dist, plotchans, pcref, pcrem, ref, started, end_at;
     int start_plot, limit_plot;
     char *rootname, *temp;
-    char buf[256], buf2[256], psbuf[256], device[256], output_filename[256];
+    char buf[2560], psbuf[2560], device[256], output_filename[256];
     char pol[3],input_filename[256], polstr[13];
     float tempfl,mb_width;
     double phase, ampl, drate, mbd, sbd;
@@ -289,7 +291,10 @@ struct type_221 **t221)
     cpgsvp (0.05, 0.35, 0.63, 0.74);
     cpgswin (xmin, xmax, 0.0, ymax);
     cpgsch (0.5);
-    cpgbox ("BCNST", 0.0, 0.0, "BCNST", 0.0, 0.0);
+    if (status.nion > 0)                // upper tics suppressed if ion display
+        cpgbox ("BNST", 0.0, 0.0, "BCNST", 0.0, 0.0);
+    else
+        cpgbox ("BCNST", 0.0, 0.0, "BCNST", 0.0, 0.0);
     cpgsch (0.7);
     cpgsci (3);
     cpgmtxt("B", 2.0, 0.5, 0.5, "singleband delay (\\gms)");
@@ -309,6 +314,29 @@ struct type_221 **t221)
         cpgslw (1);
         }
     cpgsci (1);
+                                        // ionosphere search points (iff present)
+    if (status.nion > 0)
+        {
+        for(i=0; i<status.nion; i++)
+            {
+            xr[i] = status.dtec[i][0];
+            yr[i] = status.dtec[i][1];
+                                        // debug print
+            msg("TEC %f amp %f", 0, status.dtec[i][0], status.dtec[i][1]);
+            }
+         
+        xmin = status.dtec[0][0];
+        xmax = status.dtec[status.nion-1][0];
+        cpgswin (xmin, xmax, 0.0, ymax);
+        cpgsch (0.5);
+        cpgbox ("CMST", 0.0, 0.0, "", 0.0, 0.0);
+        cpgsch (0.7);
+        cpgsci (2);
+        cpgmtxt("T", 0.5, 0.5, 0.5, "ion. TEC");
+        cpgline (status.nion, xr, yr);
+        cpgsci (1);
+        }
+
                                         /* Cross-power spectrum - amplitude */
     nlsb = nusb = numsb = 0;            /* count up total usb & lsb AP's */
     for (i=0; i<pass->nfreq; i++)
@@ -1688,10 +1716,10 @@ struct type_221 **t221)
 
     if (test_mode) strcpy (output_filename, "Suppressed by test mode");
     else strcpy (output_filename, fringename);
-                                        /* recreate input filename from output */
+                                        /* make input filename from output */
     strcpy (input_filename, fringename);
     i = strlen (input_filename);
-    while (input_filename[i] != '/')
+    while ((input_filename[i] != '/') && (i > 0))
         i--;
                                     // construct type 1 name from type 2 name
     strcpy (buf, input_filename+strlen(input_filename)-7);
