@@ -306,9 +306,6 @@ norm (struct type_pass *pass,
                                         /* FFT to X-power spectrum  */
             FFT1 (xcor, nlags*2, 1, xp_spec, 1);
 
-                                        /* apply spectral filter as needed */
-            apply_passband (sb, fdata, xp_spec, nlags*2);
-
                                         /* Adjust for Bit-shift */
                                         /* First, decode total bitshift shift */
             shift = fabs (rawdatum->delay_rate / TWO_32 * param.acc_period * SYSCLK_S);
@@ -434,6 +431,11 @@ norm (struct type_pass *pass,
             }                       // end of spectral mode code
         }                           // bottom of polarization loop
 
+                                    // also skip over this next section, if no data
+      if (sb == 0 & usb_present == 0
+       || sb == 1 & lsb_present == 0)
+          continue;
+
                                     /* apply spectral filter as needed */
       apply_passband (sb, fdata, xp_spec, nlags*2);
 
