@@ -249,6 +249,11 @@ struct type_pass *pass;
     param->ah_amp    = pass->control.adhoc_amp * conrad;
     for (i=0; i<6; i++)
         param->ah_poly[i] = pass->control.adhoc_poly[i] * conrad;
+    for (i=0; i<2; i++)
+        {
+        strcpy (param->ah_file[i], pass->control.adhoc_file[i]);
+        strcpy (param->ah_file_chans[i], pass->control.adhoc_file_chans[i]);
+        }
 
     if (do_accounting) account ("PreCorrect data");
     return (0);
